MapNavigationViewController class

Controller for a single Map Navigation instance running on the host platform.

Constructors

MapNavigationViewController(int id, ValueSetter<RouteEvent>? eventNotifier)

Properties

distanceRemaining → Future<double>
Total distance remaining in meters along route.
no setter
durationRemaining → Future<double>
Total seconds remaining on all legs.
no setter
hashCode → int
The hash code for this object.
no setterinherited
platformVersion → Future<String>
Current Device OS Version
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addImageMarkers(List<NavigationMarker> markers) → Future<List<NavigationMarker>>
Add a Marker Group to the Map imagePath is the path to the image asset, allow only image in png, jpeg, jpg format
buildAndStartNavigation({required List<LatLng> waypoints, MapOptions? options, DrivingProfile profile = DrivingProfile.drivingTraffic}) → Future<bool>
buildRoute({required List<LatLng> waypoints, MapOptions? options, DrivingProfile profile = DrivingProfile.drivingTraffic}) → Future<bool>
Build the Route Used for the Navigation
clearRoute() → Future<void>
Clear the built route and resets the map
finishNavigation() → Future<bool?>
Ends Navigation and Closes the Navigation View
initialize() → Future<void>
starts listening for events
mute(bool isMute) → Future<bool?>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onDispose() → Future
overview({MapOptions? options}) → Future<void>
queryRenderedFeatures({required Point<double> point, List<String>? layerIds, List<Object>? filter}) → Future<List>
Query the map for rendered features We only response the data of Point while click on the map.
recenter({MapOptions? options}) → Future<void>
removeAllMarkers() → Future<bool?>
removeMarkers(List<int> markerIds) → Future<bool?>
setCenterIcon(Uint8List? centerIcon) → Future<bool?>
Set Center Icon for Navigation, get by call VietMapHelper.getBytesFromAsset('assetsPath')
startNavigation({MapOptions? options}) → Future<bool?>
Starts Free Drive Mode Starts the Navigation
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited