Maneuver class

Constructors

Maneuver({List<num>? location, num? bearingBefore, num? bearingAfter, String? instruction, String? type, String? modifier, num? exit})
Maneuver.fromJson(Map<String, dynamic> json)

Properties

bearingAfter ↔ num?
getter/setter pair
bearingBefore ↔ num?
getter/setter pair
exit ↔ num?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
instruction ↔ String?
getter/setter pair
location ↔ List<num>?
getter/setter pair
modifier ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
type ↔ String?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited