MapOptions class

Configuration options for the MapBoxNavigation.

When used to change configuration, null values will be interpreted as 'do not change this configuration option'.

Constructors

MapOptions({double? initialLatitude, double? initialLongitude, String? language, double? zoom, required String apiKey, required String mapStyle, double? bearing, double? tilt, bool? alternatives, MapNavigationMode? mode, VoiceUnits? units, bool? allowsUTurnAtWayPoints, bool? enableRefresh, bool? voiceInstructionsEnabled, bool? bannerInstructionsEnabled, bool? longPressDestinationEnabled, bool? simulateRoute, Uint8List? customLocationCenterIcon, bool? isOptimized, String? mapStyleUrlDay, String? mapStyleUrlNight, EdgeInsets? padding, bool? animateBuildRoute, bool? trackCameraPosition, bool? showReportFeedbackButton = true, bool? showEndOfRouteFeedback = true, bool? isCustomizeUI = false})

Properties

allowsUTurnAtWayPoints ↔ bool?
If the value of this property is true, a returned route may require an immediate U-turn at an intermediate waypoint. At an intermediate waypoint, if the value of this property is false, each returned route may continue straight ahead or turn to either side but may not U-turn. This property has no effect if only two waypoints are specified. same as 'not continueStraight' on Android
getter/setter pair
alternatives ↔ bool?
When true, alternate routes will be presented
getter/setter pair
animateBuildRoute ↔ bool?
Should animate the building of the Route. Default is True
getter/setter pair
apiKey ↔ String
Vietmap routing api key, contact vietmap.vn to get a key
getter/setter pair
bannerInstructionsEnabled ↔ bool?
getter/setter pair
bearing ↔ double?
Bearing is the direction that the camera is pointing in and measured in degrees clockwise from north.
getter/setter pair
customLocationCenterIcon ↔ Uint8List?
Location center custom icon, get by call VietMapHelper.getBytesFromAsset('assetsPath')
getter/setter pair
enableRefresh → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
initialLatitude ↔ double?
The initial Latitude of the Map View
getter/setter pair
initialLongitude ↔ double?
The initial Longitude of the Map View
getter/setter pair
isCustomizeUI ↔ bool?
getter/setter pair
isOptimized ↔ bool?
if true, will reorder the routes to optimize navigation for time and shortest distance using the Travelling Salesman Algorithm. Always false for now
getter/setter pair
language ↔ String?
2-letter ISO 639-1 code for language. This property affects the sentence contained within the RouteStep.instructions property, but it does not affect any road names contained in that property or other properties such as RouteStep.name. Defaults to 'en' if an unsupported language is specified. The languages in this link are supported:
getter/setter pair
longPressDestinationEnabled ↔ bool?
When the user long presses on a point on the map, set that as the destination
getter/setter pair
mapStyle ↔ String
Vietmap map style url, contact vietmap.vn to get a map style url
getter/setter pair
mapStyleUrlDay ↔ String?
The Url of the style the Navigation MapView should use during the day
getter/setter pair
mapStyleUrlNight ↔ String?
The Url of the style the Navigation MapView should use at night
getter/setter pair
mode ↔ MapNavigationMode?
The navigation mode desired. Defaults to drivingWithTraffic
getter/setter pair
padding ↔ EdgeInsets?
Padding applied to the MapView when embedded
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
showEndOfRouteFeedback ↔ bool?
In iOS this will show/hide the end of route page when navigation is done. Default to True.
getter/setter pair
showReportFeedbackButton ↔ bool?
In iOS this will show/hide the feedback button. Default to True.
getter/setter pair
simulateRoute ↔ bool?
if true will simulate the route as if you were driving. Always true on iOS Simulator
getter/setter pair
tilt ↔ double?
Tilt is the camera's angle from the nadir (directly facing the Earth) and uses unit degrees. The camera's minimum (default) tilt is 0 degrees, and the maximum tilt is 60. Tilt levels use six decimal point of precision, which enables you to restrict/set/lock a map's bearing with extreme precision.
getter/setter pair
trackCameraPosition ↔ bool?
If true, the map will continuously update the user location when the location changes. Defaults to true.
getter/setter pair
units ↔ VoiceUnits?
The unit of measure said in voice instructions
getter/setter pair
voiceInstructionsEnabled ↔ bool?
getter/setter pair
zoom ↔ double?
Zoom controls the scale of the map and consumes any value between 0 and 22. At zoom level 0, the viewport shows continents and other world features. A middle value of 11 will show city level details, and at a higher zoom level, the map will begin to show buildings and points of interest.
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited
updatesMap(MapOptions newOptions) → Map<String, dynamic>

Operators

operator ==(Object other) → bool
The equality operator.
inherited