RouteLeg class

A RouteLeg object defines a single leg of a route between two waypoints. If the overall route has only two waypoints, it has a single RouteLeg object that covers the entire route. The route leg object includes information about the leg, such as its name, distance, and expected travel time. Depending on the criteria used to calculate the route, the route leg object may also include detailed turn-by-turn instructions.

Constructors

RouteLeg(String? profileIdentifier, String? name, double? distance, double? expectedTravelTime, LatLng? source, LatLng? destination, List<RouteStep>? steps)
RouteLeg.fromJson(Map<String, dynamic> json)

Properties

destination ↔ LatLng?
getter/setter pair
distance ↔ double?
getter/setter pair
expectedTravelTime ↔ double?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
name ↔ String?
getter/setter pair
profileIdentifier ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
source ↔ LatLng?
getter/setter pair
steps ↔ List<RouteStep>?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited