VietMapNavigationPlugin class

Constructors

VietMapNavigationPlugin()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

addWayPoints({required List<LatLng> wayPoints}) → Future
Adds waypoints or stops to an on-going navigation
enableOfflineRouting() → Future<bool?>
Will download the navigation engine and the user's region to allow offline routing
finishNavigation() → Future<bool?>
Ends Navigation and Closes the Navigation View
getDefaultOptions() → MapOptions
Getter to retriev default options
getDistanceRemaining() → Future<double?>
Total distance remaining in meters along route.
getDurationRemaining() → Future<double?>
Total seconds remaining on all legs.
getPlatformVersion() → Future<String?>
Current Device OS Version
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
registerRouteEventListener(ValueSetter<RouteEvent> listener) → Future
Event listener for RouteEvents
setDefaultOptions(MapOptions options) → void
setter to set default options
startFreeDrive({MapOptions? options}) → Future<bool?>
Free-drive mode is a unique Mapbox Navigation SDK feature that allows drivers to navigate without a set destination. This mode is sometimes referred to as passive navigation. Begins to generate Route Progress
startNavigation({MapOptions? options}) → Future<bool?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

instance → VietMapNavigationPlugin
get current instance of this class
no setter