NavigationView is a widget that show a map with navigation
it will response all events from the map and navigation
and return all information about the route
This callback will called when the user click on the map and response a LatLng object
which contains all information about the location where user click
This callback will called when the user long click on the map and response a LatLng object
which contains all information about the location where user long click
This callback will called whenever user change GPS location
it will response a RouteProgressEvent object, which contains all information about current route
This callback will called when the user is dragging the marker and response a int, which is the marker id
and a LatLng object, which is the location where user is dragging the marker
This callback will called when the user is drag end the marker and response a int, which is the marker id
and a LatLng object, which is the location where user is drag end the marker
This callback will be triggered when the user moves in the opposite direction or does not follow the direction of the route.
This callback will called when the user is off route and response a LatLng object
which contains all information about the location where user off route
(user is off route when user is not follow the route)