onReceiveLogMessage property
This callback will be triggered when the user receives a log message from the native side.
Implementation
final Function(String)? onReceiveLogMessage;
This callback will be triggered when the user receives a log message from the native side.
final Function(String)? onReceiveLogMessage;