onWaypointArrival property
This callback will be triggered when the user arrives at an intermediate waypoint.
Implementation
final Function(LatLng?)? onWaypointArrival;
This callback will be triggered when the user arrives at an intermediate waypoint.
final Function(LatLng?)? onWaypointArrival;