onWrongWayDetected property
This callback will called when the user is dragging the marker and response a int, which is the marker id and a LatLng object, which is the location where user is dragging the marker This callback will called when the user is drag end the marker and response a int, which is the marker id and a LatLng object, which is the location where user is drag end the marker This callback will be triggered when the user moves in the opposite direction or does not follow the direction of the route.
Implementation
// final Function(int, LatLng)? onMarkerDragging;
/// This callback will called when the user is drag end the marker and response a [int], which is the marker id
/// and a [LatLng] object, which is the location where user is drag end the marker
// final Function(int, LatLng)? onMarkerDragEnd;
/// This callback will be triggered when the user moves in the opposite direction or does not follow the direction of the route.
final VoidCallback? onWrongWayDetected;