distanceToOffRoute property
The maximum allowed distance for the user to deviate from the current route. If you deviate from the route beyond this distance, the SDK will automatically trigger a reroute to compute a new path based on your actual location. Unit: meters (m). Default value: 50m.
Implementation
double? distanceToOffRoute;