upcomingBannerText property
Banner text of the maneuver after the upcoming one — source of a "then …" sign. Null when there is no such maneuver on this leg.
Implementation
String? upcomingBannerText;
Banner text of the maneuver after the upcoming one — source of a "then …" sign. Null when there is no such maneuver on this leg.
String? upcomingBannerText;