NavigationView class

Inheritance

Constructors

NavigationView is a widget that show a map with navigation it will response all events from the map and navigation and return all information about the route
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
mapOptions → MapOptions
Setting navigation options for the map
final
onArrival → VoidCallback?
This callback will called when the user is arrival to the destination
final
onMapClick → dynamic Function(LatLng?, Point<num>?)?
This callback will called when the user click on the map and response a LatLng object which contains all information about the location where user click
final
onMapCreated → dynamic Function(MapNavigationViewController)
This callback will called when map is created
final
onMapLongClick → dynamic Function(LatLng?, Point<num>?)?
This callback will called when the user long click on the map and response a LatLng object which contains all information about the location where user long click
final
onMapMove → VoidCallback?
This callback will called when the map is start move
final
onMapMoveEnd → VoidCallback?
This callback will called when the map is moved end
final
onMapReady → VoidCallback?
This callback will called when the map is ready
final
onMapRendered → VoidCallback?
This callback will called when the map is rendered successfully and complete show all elements of the map
final
onMarkerClicked → dynamic Function(int?)?
This callback will called when the user click on the marker and response a int, which is the marker id
final
onNavigationCancelled → VoidCallback?
This callback will called when the navigation is cancelled (user click on the cancel button on the navigation view)
final
onNavigationFinished → VoidCallback?
This callback will called when the navigation is finished (user arrived destination)
final
onNavigationRunning → VoidCallback?
This callback will called when the navigation is running
final
onNewRouteSelected → dynamic Function(DirectionRoute)?
This callback will called when the user select a new route and response a DirectionRoute object which contains all information about the new route
final
onRouteBuildFailed → dynamic Function(String?)?
This callback will called when the route is built failed and response a message
final
onRouteBuilding → VoidCallback?
This callback will called when the route is building
final
onRouteBuilt → dynamic Function(DirectionRoute)?
This callback will called when the route is built successfully and response a DirectionRoute object which contains all information about the route
final
onRouteProgressChange → dynamic Function(RouteProgressEvent)?
This callback will called whenever user change GPS location it will response a RouteProgressEvent object, which contains all information about current route
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
userOffRoute → dynamic Function(LatLng?)?
This callback will called when the user is off route and response a LatLng object which contains all information about the location where user off route (user is off route when user is not follow the route)
final

Methods

createElement() → StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() → State<NavigationView>
Creates the mutable state for this widget at a given location in the tree.
override
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited